@@ -19,6 +19,7 @@ from urllib.parse import urljoin
 from ldf_adapter.config import CONFIG
 from ldf_adapter import utils
 from ldf_adapter.logsetup import jsonlogger
+from ldf_adapter.backend import generic
 
 logger = logging.getLogger(__name__)
 
@@ -57,9 +58,13 @@ class BwIdmConnection:
         fail = kwargs.pop("fail", True)
 
         url_fragments = map(str, url_fragments)
-        url_fragments = map(lambda frag: requests.utils.quote(frag, safe=""), url_fragments)
+        url_fragments = map(
+            lambda frag: requests.utils.quote(frag, safe=""), url_fragments
+        )
         url = reduce(
-            lambda acc, frag: urljoin(acc, frag) if acc.endswith("/") else urljoin(acc + "/", frag),
+            lambda acc, frag: urljoin(acc, frag)
+            if acc.endswith("/")
+            else urljoin(acc + "/", frag),
             url_fragments,
             CONFIG.backend.bwidm.url,
         )
@@ -71,7 +76,9 @@ class BwIdmConnection:
 
         if fail:
             if not rsp.ok:
-                logger.error("Server responded with: {}".format(rsp.content.decode("utf-8")))
+                logger.error(
+                    "Server responded with: {}".format(rsp.content.decode("utf-8"))
+                )
             rsp.raise_for_status()
 
         return rsp
@@ -80,16 +87,18 @@ class BwIdmConnection:
 BWIDM = BwIdmConnection(CONFIG)
 
 
-class User:
+class User(generic.User):
     ATTR_USERNAME = "urn:oid:0.9.2342.19200300.100.1.1"
     ATTR_ORG_ID = "http://bwidm.de/bwidmOrgId"
     VALUE_USER_ACTIVE = "ACTIVE"
     VALUE_USER_INACTIVE = "ON_HOLD"
 
-    def __init__(self, userinfo):
+    def __init__(self, userinfo, **hooks):
+        super().__init__(userinfo, **hooks)
         self.info = userinfo
         self.primary_group = Group(userinfo.primary_group)
         self.force_username = None
+        self.post_create_script = CONFIG.backend.bwidm.post_create_script
 
     def exists(self):
         """
@@ -108,7 +117,9 @@ class User:
 
     def _is_active(self):
         status = self.reg_info()["userStatus"]
-        logger.debug("User {} is {} on service BWIDM".format(self.info.unique_id, status))
+        logger.debug(
+            "User {} is {} on service BWIDM".format(self.info.unique_id, status)
+        )
         return status == self.VALUE_USER_ACTIVE
 
     def _is_registered(self):
@@ -118,13 +129,17 @@ class User:
         """
         # FIXME: Consider putting this request into the global user object (to reduce load on regapp)
         ssn = CONFIG.backend.bwidm.service_name
-        registrations = BWIDM.get("external-reg", "find", "externalId", self.info.unique_id)
+        registrations = BWIDM.get(
+            "external-reg", "find", "externalId", self.info.unique_id
+        )
         # find registrations
         number_of_registrations = 0
         try:
             logger.debug("logging registrations to jsonlog")
             jsonlogger.debug(
-                json.dumps(registrations.json, sort_keys=True, indent=4, separators=(",", ": "))
+                json.dumps(
+                    registrations.json, sort_keys=True, indent=4, separators=(",", ": ")
+                )
             )
         except TypeError:
             pass
@@ -149,7 +164,9 @@ class User:
         ).json()
 
         other_users_with_name = [
-            user for user in users_with_name if user["externalId"] != self.info.unique_id
+            user
+            for user in users_with_name
+            if user["externalId"] != self.info.unique_id
         ]
         # logger.debug (F"other_users: {other_users_with_name}")
         logger.debug(f"Found {len(other_users_with_name)} with same username")
@@ -161,7 +178,9 @@ class User:
             logger.error(
                 "Username '{}' is already used by\n    {}".format(
                     self.info.username,
-                    ",\n    ".join(map(lambda u: u["externalId"], other_users_with_name)),
+                    ",\n    ".join(
+                        map(lambda u: u["externalId"], other_users_with_name)
+                    ),
                 )
             )
         else:
@@ -176,7 +195,8 @@ class User:
             """Safely convert a response to json"""
             if resp.status_code != 200:
                 logger.debug(
-                    "Error %d reading from remote: \n%s\n" % (resp.status_code, str(resp.text))
+                    "Error %d reading from remote: \n%s\n"
+                    % (resp.status_code, str(resp.text))
                 )
                 os._exit(1)  # or raise or return None?
             try:
@@ -200,7 +220,9 @@ class User:
             logger.error("Error: I could not find the username in the database.")
             logger.error("  Most likely the user is not registered for this service\n")
             logger.error(f"  {e}")
-            logger.error(json.dumps(resp_json, sort_keys=True, indent=4, separators=(",", ": ")))
+            logger.error(
+                json.dumps(resp_json, sort_keys=True, indent=4, separators=(",", ": "))
+            )
         return None
 
     def set_username(self, username):
@@ -221,7 +243,9 @@ class User:
             BWIDM.get("external-user", "activate", "externalId", self.info.unique_id)
         else:
             logger.info("Creating user {unique_id}".format(**self.info))
-            BWIDM.post("external-user", "create", json={"externalId": self.info.unique_id})
+            BWIDM.post(
+                "external-user", "create", json={"externalId": self.info.unique_id}
+            )
 
     def register(self):
         """register user for the configured service"""
@@ -230,7 +254,9 @@ class User:
             rsp = BWIDM.get("external-reg", "find", "externalId", ext_id)
 
             try:
-                return next(filter(lambda reg: reg["registryStatus"] == "ACTIVE", rsp.json()))
+                return next(
+                    filter(lambda reg: reg["registryStatus"] == "ACTIVE", rsp.json())
+                )
             except StopIteration:
                 return {"lastReconcile": None}
 
@@ -322,12 +348,16 @@ class User:
 
             # Remove user from groups he should not be a member of
             to_be_removed_from = [
-                g for g in current_groups if g["id"] not in (ng["id"] for ng in new_groups)
+                g
+                for g in current_groups
+                if g["id"] not in (ng["id"] for ng in new_groups)
             ]
 
             # Only add user to groups she is not already a member of
             to_be_added_to = [
-                g for g in new_groups if g["id"] not in (cg["id"] for cg in current_groups)
+                g
+                for g in new_groups
+                if g["id"] not in (cg["id"] for cg in current_groups)
             ]
 
             if to_be_removed_from:
@@ -404,7 +434,9 @@ class User:
         """
         current_state = self.reg_info()
         new_state = utils.dictmerge(current_state, state_updates)
-        utils.log_dictdiff(utils.dictdiff(current_state, new_state), log_function=logger.info)
+        utils.log_dictdiff(
+            utils.dictdiff(current_state, new_state), log_function=logger.info
+        )
         try:
             logger.debug(
                 f"current_state: {current_state['attributeStore']['urn:oid:0.9.2342.19200300.100.1.1']}"
@@ -438,7 +470,9 @@ class User:
             jsonlogger.debug(f"current_state: {formatted_json}")
 
             logger.debug("  logging new_to jsonlog")
-            formatted_json = json.dumps(new_state, sort_keys=True, indent=4, separators=(",", ": "))
+            formatted_json = json.dumps(
+                new_state, sort_keys=True, indent=4, separators=(",", ": ")
+            )
             jsonlogger.debug(f"new state for regapp:  {formatted_json}")
         except:
             pass
@@ -446,11 +480,13 @@ class User:
 
     def reg_info(self, json=True, **kwargs):
         # FIXME: Cache this functions results!
-        rsp = BWIDM.get("external-user", "find", "externalId", self.info.unique_id, **kwargs)
+        rsp = BWIDM.get(
+            "external-user", "find", "externalId", self.info.unique_id, **kwargs
+        )
         return rsp.json() if json else rsp.content
 
 
-class Group:
+class Group(generic.Group):
     def __init__(self, name):
         self.name = name
 
@@ -459,7 +495,9 @@ class Group:
         # CONFIG.backend.bwidm.service_name
         return (
             b"no such group"
-            not in BWIDM.get("group-admin", "find", "name", self.name, fail=False).content
+            not in BWIDM.get(
+                "group-admin", "find", "name", self.name, fail=False
+            ).content
         )
 
     def create(self):
@@ -469,7 +507,9 @@ class Group:
 
         if self.name != rsp["name"]:
             logger.warning(
-                "Groupname changed from {} to {} by BWIDM".format(self.name, rsp["name"])
+                "Groupname changed from {} to {} by BWIDM".format(
+                    self.name, rsp["name"]
+                )
             )
             self.name = rsp["name"]
 
